@@ -46,6 +46,8 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns `terms`
 #' (the selectors or variables selected) and `value` (number of unique tokens).
+#' 
+#' @template case-weights-not-supported
 #'
 #' @seealso [step_tokenize()] to turn characters into [`tokens`][tokenlist()]
 #' @family Steps for Token Modification
@@ -171,7 +173,7 @@ prep.step_tokenfilter <- function(x, training, info = NULL, ...) {
 #' @export
 bake.step_tokenfilter <- function(object, new_data, ...) {
   col_names <- object$columns
-  # for backward compat
+  check_new_data(col_names, object, new_data)
 
   for (i in seq_along(col_names)) {
     if (is.null(object$filter_fun)) {
@@ -191,7 +193,7 @@ bake.step_tokenfilter <- function(object, new_data, ...) {
   }
   new_data <- factor_to_text(new_data, col_names)
 
-  as_tibble(new_data)
+  new_data
 }
 
 #' @export
