@@ -185,6 +185,8 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns `terms`
 #' (the selectors or variables selected) and `value` (unit of tokenization).
+#' 
+#' @template case-weights-not-supported
 #'
 #' @seealso [step_untokenize()] to untokenize.
 #' @family Steps for Tokenization
@@ -306,7 +308,7 @@ prep.step_tokenize <- function(x, training, info = NULL, ...) {
 #' @export
 bake.step_tokenize <- function(object, new_data, ...) {
   col_names <- object$columns
-  # for backward compat
+  check_new_data(col_names, object, new_data)
 
   for (i in seq_along(col_names)) {
     new_data[, col_names[i]] <- tokenizer_fun(
@@ -316,7 +318,7 @@ bake.step_tokenize <- function(object, new_data, ...) {
       token = object$custom_token[[i]]
     )
   }
-  as_tibble(new_data)
+  new_data
 }
 
 #' @export
