@@ -67,12 +67,31 @@ test_that("hashing output width changes accordingly with num_terms", {
   expect_false(all(unsigned$texthash_text_2 == signed$texthash_text_2))
 })
 
+test_that("bake method errors when needed non-standard role columns are missing", {
+  tokenized_test_data <- recipe(~text, data = test_data) %>%
+    step_tokenize(text) %>%
+    prep() %>%
+    bake(new_data = NULL)
+  
+  rec <- recipe(tokenized_test_data) %>%
+    update_role(text, new_role = "predictor") %>%
+    step_texthash(text) %>%
+    update_role(text, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+  
+  trained <- prep(rec, training = tokenized_test_data, verbose = FALSE)
+  
+  expect_error(bake(trained, new_data = tokenized_test_data[, -1]),
+               class = "new_data_missing_column")
+})
+
 test_that("printing", {
   skip_if_not_installed("text2vec")
   rec <- rec %>%
     step_tokenize(text) %>%
     step_texthash(text)
   expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
 
 test_that("keep_original_cols works", {
