@@ -124,10 +124,23 @@ test_that("tokenization doesn't includes lemma attribute when unavaliable", {
   )
 })
 
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(~text, data = test_data) %>%
+    step_tokenize(text) %>%
+    update_role(text, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+  
+  trained <- prep(rec, training = test_data, verbose = FALSE)
+  
+  expect_error(bake(trained, new_data = test_data[, -1]),
+               class = "new_data_missing_column")
+})
+
 test_that("printing", {
   rec <- rec %>%
     step_tokenize(text)
   expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
 
 test_that("empty selection prep/bake is a no-op", {
